@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -21,7 +21,7 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = hasRequest('parent_discoveryid') ? _('Configuration of graph prototypes') : _('Configuration of graphs');
 $page['file'] = 'graphs.php';
-$page['scripts'] = ['colorpicker.js', 'multiselect.js', 'items.js', 'multilineinput.js'];
+$page['scripts'] = ['colorpicker.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -714,7 +714,6 @@ else {
 	$options = [
 		'output' => ['graphid', 'name', 'templateid', 'graphtype', 'width', 'height'],
 		'selectDiscoveryRule' => ['itemid', 'name'],
-		'selectGraphDiscovery'	=> ['status', 'ts_delete'],
 		'selectHosts' => ($data['hostid'] == 0) ? ['name'] : null,
 		'graphids' => zbx_objectValues($data['graphs'], 'graphid'),
 		'preservekeys' => true
@@ -725,43 +724,13 @@ else {
 		$data['graphs'] = API::GraphPrototype()->get($options);
 	}
 	else {
-		$data['graphs'] = API::Graph()->get($options + ['selectGraphDiscovery' => ['ts_delete']]);
+		$data['graphs'] = API::Graph()->get($options + ['selectGraphDiscovery' => ['status', 'ts_delete']]);
 	}
 
 	foreach ($data['graphs'] as $gnum => $graph) {
 		$data['graphs'][$gnum]['graphtype'] = graphType($graph['graphtype']);
 	}
 
-	if (!hasRequest('parent_discoveryid')) {
-		$items = API::Item()->get([
-			'output' => ['itemid'],
-			'selectGraphs' => ['graphid'],
-			'selectItemDiscovery' => ['ts_delete'],
-			'graphids' => array_keys($data['graphs']),
-			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_CREATED]
-		]);
-
-		foreach ($items as $item) {
-			$ts_delete = $item['itemDiscovery']['ts_delete'];
-
-			if ($ts_delete == 0) {
-				continue;
-			}
-
-			foreach (array_column($item['graphs'], 'graphid') as $graphid) {
-				if (!array_key_exists('ts_delete', $data['graphs'][$graphid]['graphDiscovery'])) {
-					$data['graphs'][$graphid]['graphDiscovery']['ts_delete'] = $ts_delete;
-				}
-				else {
-					$graph_ts_delete = $data['graphs'][$graphid]['graphDiscovery']['ts_delete'];
-					$data['graphs'][$graphid]['graphDiscovery']['ts_delete'] = ($graph_ts_delete > 0)
-						? min($ts_delete, $graph_ts_delete)
-						: $ts_delete;
-				}
-			}
-		}
-	}
-
 	order_result($data['graphs'], $sort_field, $sort_order);
 
 	if ($data['hostid'] == 0) {
