@@ -21,7 +21,6 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of discovery rules');
 $page['file'] = 'host_discovery.php';
-$page['scripts'] = ['multilineinput.js', 'items.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -234,7 +233,7 @@ $fields = [
 	'filter_rst' =>						[T_ZBX_STR, O_OPT, null,	null,		null],
 	'filter_groupids' =>				[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,	null],
 	'filter_hostids' =>					[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,	null],
-	'filter_name' =>					[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_name' =>					[T_ZBX_STR, O_OPT, P_NO_TRIM,		null,	null],
 	'filter_key' =>						[T_ZBX_STR, O_OPT, null,	null,		null],
 	'filter_type' =>					[T_ZBX_INT, O_OPT, null,
 											IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE,
